
%%%
%%% Compute and plot IRF (impulse response function) to certain shocks
%%%

%%%
%%% this program is called by runThomas, but can be called independently
%%% once the log-linear approximation for the fixed cost DSGE model has
%%% been computed

%%%
%%% first step:
%%% Choose the impulse using the shockTFP
%%% 

numState = size(N,1); %  number of state variables
simplerbc;
listinterestrbc=[indexNrbc, indexIrbc, indexYrbc];


    impulse = zeros(1,numState);
    impulse(indexA) = 1 ;
    impulserbc = zeros(numStaterbc,1);
    impulserbc(indexArbc) = 1 ;



%%%
%%% Computation of IRF using log-linear solution
%%%

T=31;
imprep1=zeros(number,T);

for k=1:T
    imprep1(1:numState,k)=N^(k-1)*impulse';
    imprep1(numState+1:end,k)=M*N^(k-1)*impulse' ;
end

%%%
%%% Choose what to plot:
%%%

listinterestIR= [indexA, indexK, indexK+2, indexK+5,indexAlpha, indexAlpha+2,...
    indexTheta, indexTheta+2, indexTheta+5,indexI, indexI+2, indexNA, indexIA, indexYA];


%%%
%%% Computation of IRF of RBC model for comparison, w/ or w/o adj cost
%%%


totalsize=length([Nrbc;Mrbc]);
imprep3 = zeros(totalsize,T);
for k=1:T
    imprep3(1:length(Nrbc),k)=Nrbc^(k-1)*impulserbc;
    imprep3(length(Nrbc)+1:totalsize,k)=[Mrbc]*Nrbc^(k-1)*impulserbc;
end



    for i=1:length(listinterestIR)-3;
        figure;
        plot((0:1:T-1),imprep1(listinterestIR(i),:),'b+-');
        title(['IR of :  ',char(listvarTTT(listinterestIR(i)))]);
        grid on;
        xlabel('years after shock'); ylabel('% deviation from steady-state');
    end

    figure;
    plot((0:1:T-1),imprep1(indexNA,:),'b+-');
    hold on;
    plot((0:1:T-1),imprep3(indexNrbc,:),'g-o');
    legend('Fixed Cost','RBC')
    xlabel('years after shock'); ylabel('% deviation from steady-state');
    title('IR of Employment (RBC circle, Fixed Cost Model crosses)')
    grid on;

    figure;
    plot((0:1:T-1),imprep1(indexYA,:),'b+-');
    hold on;
    plot((0:1:T-1),imprep3(indexYrbc,:),'g-o');
    legend('Fixed Cost','RBC')
    xlabel('years after shock'); ylabel('% deviation from steady-state');
    title('IR of Output (RBC circle, Fixed Cost Model crosses)')
    grid on;

    figure;
    plot((0:1:T-1),imprep1(indexIA,:),'b+-');
    hold on;
    xlabel('years after shock'); ylabel('% deviation from steady-state');
    plot((0:1:T-1),imprep3(indexIrbc,:),'g-o');
    legend('Fixed Cost','RBC'); grid on;
    title('IR of Investment (RBC circle, Fixed Cost Model crosses)')

    figure;
    plot((0:1:J),imprep1(indexTheta:indexTheta+J,2),'kv-','LineWidth',2);
    hold on;plot((0:1:J),imprep1(indexTheta:indexTheta+J,4),'b>--','LineWidth',2);
    hold on;plot((0:1:J),imprep1(indexTheta:indexTheta+J,7),'gd-','LineWidth',2);
    hold on;plot((0:1:J),imprep1(indexTheta:indexTheta+J,10),'ro-','LineWidth',2);
    xlabel('vintage'); grid on;
    ylabel('% deviation from steady-state');
    legend('1 period after shock','3 periods after shock','6 periods after shock','9 periods after shock',3)
    title('IR of theta');

    figure;plot((0:1:J-1),imprep1(indexAlpha:indexAlpha+J-1,1),'o-');
    xlabel('vintage');ylabel('% deviation from steady-state');
    grid on; title(' IRF of alphas at t=0 by vintage')

%%%%%%%%%%%%%%%%%%%%%%%%%%%%%
%%% quick summary of IRFs %%%
%%%%%%%%%%%%%%%%%%%%%%%%%%%%%

resultt = [imprep1(indexK,2),imprep1(indexTheta,2),imprep1(indexTheta+5,2),imprep1(indexAlpha,1)];
re=[imprep1(indexIA,1),imprep3(indexIrbc,1)];

disp('=============================')
disp('quick summary of IRF')
disp('=============================')
fmt = ' %12.4f ';
row = {'Basic IR'} ;
head = {'          dk0/dTFP','   dTheta0/dTFP','dTheta5/dTFP','dAlpha0/dTFP'};
texprint(resultt, fmt, head, row) ;
head={'            dIA/dTFP','   dIA/dTFP (RBC)'};
row = {'Comparison'} ;
texprint(re, fmt, head, row) ;
